==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/xtchgnumHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "l͈͂ɂu"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-f*/
#define FLDT "ϊ鐔lڃXg"
#define FLDC "Ŏw肵ڂ̐l-R-vŎw肵l͈̓Xgђu񃊃Xgɏ]Ēu"
#define FLDF NULL

/*-R*/
#define LSTT "l͈̓Xg"
#define LSTC "uΏۂƂȂ鐔l͈͂w肷(1.1_2.5 : 1.1ȏ2.5)B"

/*-v*/
#define VALT "u񃊃Xg"
#define VALC "-RŎw肵l͈͂ɑΉuw肷B"

/*-O*/
#define OTHT "͈͊O"
#define OTHC "-RŎw肵l͈̓XĝƂvȂluƂ̕(w肪ȂNULLƂȂ)B"

/*-F*/
#define FRPT "͈͊Oڂ̒lƂďo"
#define FRPC "-RŎw肵l͈̓XĝƂvȂĺA̍ڂ̒l̂܂܏o͂B"

/*-r*/
#define REQT "-R͈̔͂'`傫`ȉ'ƂĈ"
#define REQC "̃IvVw肷邱ƂɂāA'1.1_2.5''1.1傫2.5ȉ'ƂĈB"

/*-A*/
#define NEWT C_NEWT
#define NEWC C_NEWC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "-fŎw肵ڂɂāA-R̐l͈͏-v̒uɂAڂ̒luB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtchgnum -f z -R MIN,5,10,MAX -v ,, -i dat.xt -o rsl.xt\n\
xtchgnum -f z -R 0,5,10,20 -v ,, -O ͈͊O -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtchgstr,xtsed"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4.tar.gz: musashi-core-1.0.4/help/ja-sjis/xtchgnumHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "l͈͂ɂu"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-f*/
#define FLDT "ϊ鐔lڃXg"
#define FLDC "Ŏw肵ڂ̐l-R-vŎw肵l͈̓Xgђu񃊃Xgɏ]Ēu"
#define FLDF NULL

/*-R*/
#define LSTT "l͈̓Xg"
#define LSTC "uΏۂƂȂ鐔l͈͂w肷(1.1_2.5 : 1.1ȏ2.5)B"

/*-v*/
#define VALT "u񃊃Xg"
#define VALC "-RŎw肵l͈͂ɑΉuw肷B"

/*-O*/
#define OTHT "͈͊O"
#define OTHC "-RŎw肵l͈̓XĝƂvȂluƂ̕(w肪ȂNULLƂȂ)B"

/*-F*/
#define FRPT "͈͊Oڂ̒lƂďo"
#define FRPC "-RŎw肵l͈̓XĝƂvȂĺA̍ڂ̒l̂܂܏o͂B"

/*-r*/
#define REQT "-R͈̔͂'`傫`ȉ'ƂĈ"
#define REQC "̃IvVw肷邱ƂɂāA'1.1_2.5''1.1傫2.5ȉ'ƂĈB"

/*-A*/
#define NEWT C_NEWT
#define NEWC C_NEWC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "-fŎw肵ڂɂāA-R̐l͈͏-v̒uɂAڂ̒luB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtchgnum -f z -R MIN,5,10,MAX -v ,, -i dat.xt -o rsl.xt\n\
xtchgnum -f z -R 0,5,10,20 -v ,, -O ͈͊O -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtchgstr,xtsed"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
